@@ -2,7 +2,7 @@
 Author: Elite_zhangjunjie
 CreateDate: 
 LastEditors: Elite_zhangjunjie
-LastEditTime: 2022-05-16 19:54:02
+LastEditTime: 2022-05-20 11:47:19
 Description: 
 '''
 
@@ -13,7 +13,7 @@ class ECKinematics(BaseEC):
     """EC运动学类,提供了机器人本身的运动学相关接口
     """
 # 运动学服务
-    def inverse_kinematic(self, pose: List[float] ,ref_joint: Optional[List[float]] = None, unit_type: Optional[int] = None) -> List[float]:
+    def get_inverse_kinematic(self, pose: List[float] ,ref_joint: Optional[List[float]] = None, unit_type: Optional[int] = None) -> List[float]:
         """运动学逆解
 
         Args
@@ -38,7 +38,7 @@ class ECKinematics(BaseEC):
                 return self.send_CMD("inverseKinematic",{"targetPose":pose,"referencePos":ref_joint})
 
 
-    def forward_kinematic(self, joint: List[float], unit_type: Optional[int] = None) -> List[float]:
+    def get_forward_kinematic(self, joint: List[float], unit_type: Optional[int] = None) -> List[float]:
         """运动学正解
 
         Args
@@ -93,13 +93,13 @@ class ECKinematics(BaseEC):
             return self.send_CMD("poseInv",{"pose1":pose})
         
         
-    def cartPose_2_userPose(self, cart_pose: List[float], user_no: int, unit_type: Optional[int] = None) -> List[float]:
+    def convert_base_pose_to_user_pose(self, base_pose: List[float], user_num: int, unit_type: Optional[int] = None) -> List[float]:
         """基坐标系位姿转化为用户坐标系位姿
 
         Args
         ----
             cart_pose (List[float]): 基坐标系下的位姿数据
-            user_no (int): 用户坐标系号
+            user_num (int): 用户坐标系号
             unit_type (int, optional): 输入和返回位姿的单位类型,0:角度, 1:弧度, 不填默认弧度. Defaults to None.
 
         Returns
@@ -107,18 +107,18 @@ class ECKinematics(BaseEC):
             List[float]: 用户坐标系下的位姿信息
         """
         if unit_type is not None:
-            return self.send_CMD("convertPoseFromCartToUser",{"TargetPose":cart_pose, "userNo":user_no, "unit_type":unit_type})
+            return self.send_CMD("convertPoseFromCartToUser",{"TargetPose":base_pose, "userNo":user_num, "unit_type":unit_type})
         else:
-            return self.send_CMD("convertPoseFromCartToUser",{"TargetPose":cart_pose, "userNo":user_no})
+            return self.send_CMD("convertPoseFromCartToUser",{"TargetPose":base_pose, "userNo":user_num})
             
         
-    def userPose_2_cartPose(self, user_pose: List[float], user_no: int, unit_type: Optional[int] = None) -> List[float]:
+    def convert_user_pose_to_base_pose(self, user_pose: List[float], user_num: int, unit_type: Optional[int] = None) -> List[float]:
         """用户坐标系转化为基坐标系
 
         Args
         ----
             user_pose (List[float]): 用户坐标系下的数据
-            user_no (int): 用户坐标系号
+            user_num (int): 用户坐标系号
             unit_type (int, optional): 输入和返回位姿的单位类型,0:角度, 1:弧度, 不填默认弧度. Defaults to None.
 
         Returns
@@ -130,6 +130,6 @@ class ECKinematics(BaseEC):
 
         """
         if unit_type is not None:
-            return self.send_CMD("convertPoseFromUserToCart",{"TargetPose":user_pose, "userNo":user_no, "unit_type":unit_type})
+            return self.send_CMD("convertPoseFromUserToCart",{"TargetPose":user_pose, "userNo":user_num, "unit_type":unit_type})
         else:
-            return self.send_CMD("convertPoseFromUserToCart",{"TargetPose":user_pose, "userNo":user_no})
+            return self.send_CMD("convertPoseFromUserToCart",{"TargetPose":user_pose, "userNo":user_num})
